import {h, Component} from 'preact'
import TopPanel from './js/nav-top'
import MiddlePanel from './js/nav-middle'
import BottomPanel from './js/nav-bottom'
import Background from './js/background'

export default class Nav extends Component {
  constructor (props) {
    super(props)

    this.state = {
      isMobile: this.props.isMobile || false,
      isOpen: false,
      activeSection: -1,
      breakpoint: 895
    }

    this.env = this.props.environment || 'com'

    this.toggle = this.toggle.bind(this)
    this.setActiveSection = this.setActiveSection.bind(this)
    this.onResize = this.onResize.bind(this)
    this.setNavOffset = this.setNavOffset.bind(this)
    this.resetNav = this.resetNav.bind(this)
  }

  componentDidMount () {
    this.onResize()
    window.addEventListener('resize', this.onResize, {passive: true})
    window.addEventListener('scroll', this.setNavOffset, {passive: true})

    this.navStyle = document.querySelector('.m-nav').style
    this.navBGStyle = document.querySelector('.m-nav-bg').style
  }

  onResize () {
    const {isMobile, breakpoint} = this.state
    const {innerWidth} = window

    if (isMobile && innerWidth > breakpoint) {
      this.setState({
        isMobile: false, isOpen: false, activeSection: -1
      }, () => this.resetNav())
      document.body.classList.remove('no-scroll')
    } else if (!isMobile && innerWidth <= breakpoint) {
      this.setState({
        isMobile: true, activeSection: -1
      }, () => this.setNavOffset())
    }
  }

  setNavOffset () {
    if (!this.props.isTopNavHidden && !this.props.disableMobileNavOffset && this.state.isMobile) {
      if (window.pageYOffset >= 45) {
        this.navStyle.position = 'fixed'
        this.navStyle.top = '-45px'
        this.navBGStyle.top = '-45px'
        this.navBGStyle.height = 'calc(100% - 50px)'
      } else {
        this.navStyle.position = 'absolute'
        this.navStyle.top = '0'
        this.navBGStyle.top = `-${window.pageYOffset}px`
        this.navBGStyle.height = `calc(100% - ${95 - window.pageYOffset}px)`
      }
    }
  }

  resetNav () {
    if (!this.props.isTopNavHidden && !this.props.disableMobileNavOffset) {
      this.navStyle.position = 'fixed'
      this.navStyle.top = '0px'
      this.navBGStyle.top = '0px'
      this.navBGStyle.height = '600px'
    }
  }

  setActiveSection (activeSection) {
    this.setState({
      activeSection: activeSection,
      isOpen: activeSection > -1
    })
  }

  toggle () {
    const isOpen = !this.state.isOpen

    if (this.state.isMobile) {
      document.body.classList.toggle('no-scroll', isOpen)
    }

    this.setState({isOpen})
  }

  render (props, state) {
    const active = state.activeSection
    const mobile = state.isMobile

    return <nav
      style={props.isTopNavHidden ? {top: '-45px'} : null}
      class='m-nav m-nav-flex-y'>
      <TopPanel
        downloadUrl={props.downloadUrl}
        downloadJmpValue={props.downloadJmpValue}
        host={this.env === 'com' ? '' : 'https://www.mongodb.com'}
        sections={props.topSections}
        searchUrl={props.searchUrl}
        contactUrl={props.contactUrl} />
      <MiddlePanel
        activeSection={active}
        isMobile={mobile}
        logoUrl={props.logoUrl}
        tagline={props.tagline}
        logoLink={props.logoLink}
        sections={props.sections}
        toggle={this.toggle}
        setActiveSection={this.setActiveSection} />
      <Background
        isMobile={mobile}
        setActiveSection={this.setActiveSection}
        isOpaque={state.isOpen || active !== -1 || props.isOpaque}
        isOpen={state.isOpen}
        isTopNavHidden={props.isTopNavHidden}>
        <BottomPanel
          isMobile={mobile}
          activeSection={active}
          midSections={props.sections}
          sections={props.subsections} />
      </Background>
    </nav>
  }
}
