import {h, Component} from 'preact'

export default class NavBackground extends Component {
  constructor (props) {
    super(props)

    this.state = {
      isOpaque: this.props.isOpaque,
      isOpen: this.props.isOpen,
      backgroundOpacity: 0.9
    }

    this.onScroll = this.onScroll.bind(this)
    this.onWindowPress = this.onWindowPress.bind(this)
  }

  componentDidMount () {
    window.addEventListener('scroll', () => {
      if (this.RafId || this.props.isOpen) return

      this.RafId = requestAnimationFrame(this.onScroll)
    }, {passive: true})
  }

  onScroll () {
    const y = window.scrollY || window.pageYOffset
    const { isOpaque } = this.state

    if (y >= 50 && !isOpaque) {
      this.setState({ isOpaque: true })
    } else if (!this.props.isOpaque && y < 50 && isOpaque) {
      this.setState({ isOpaque: false })
    }

    this.RafId = undefined
  }

  onWindowPress (e) {
    let el = e.target
    let toTrigger = true

    while (el) {
      if (el !== undefined &&
          el.className !== undefined &&
          el.className.indexOf !== undefined &&
          el.className.indexOf('m-nav') > -1) {
        toTrigger = false
        break
      }

      el = el.parentNode
    }

    if (toTrigger) {
      this.props.setActiveSection(-1)
      window.removeEventListener('touchend', this.onWindowPress)
      window.removeEventListener('mouseup', this.onWindowPress)
    }
  }

  componentWillReceiveProps (props) {
    const obj = {}

    if (props.isOpen) {
      obj.isOpen = props.isOpen
    }

    if (props.isOpaque) {
      const y = window.scrollY || window.pageYOffset
      obj.isOpaque = (y < 50) ? props.isOpaque : true
    }

    this.setState(obj)

    if (!props.isOpen) return

    window.addEventListener('touchend', this.onWindowPress, {passive: true})
    window.addEventListener('mouseup', this.onWindowPress, {passive: true})
  }

  render ({isOpen, isTopNavHidden, children}, {isOpaque}) {
    let classnames = 'm-nav-bg m-nav-flex-x'
    if (isOpen) classnames += ' m-nav-bg-open'
    if (isOpaque) classnames += ' m-nav-bg-opaque'

    return <div
      ref={el => { this.root = el }}
      class={classnames}
      style={isTopNavHidden ? { top: '-45px' } : null}>
      {children}
    </div>
  }
}
